<?php
/**
 * @author Lukas Reschke <lukas@owncloud.com>
 *
 * @copyright Copyright (c) 2016, ownCloud, Inc.
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License, version 3,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License, version 3,
 * along with this program.  If not, see <http://www.gnu.org/licenses/>
 *
 */

namespace OC\Repair;

use OC\Hooks\BasicEmitter;

/**
 * Class BrokenUpdaterRepair fixes some issues caused by bugs in the ownCloud
 * updater below version 9.0.2.
 *
 * FIXME: This file should be removed after the 9.0.2 release. The update server
 * is instructed to deliver 9.0.2 for 9.0.0 and 9.0.1.
 *
 * @package OC\Repair
 */
class BrokenUpdaterRepair extends BasicEmitter implements \OC\RepairStep {

	public function getName() {
		return 'Manually copies the third-party folder changes since 9.0.0 due ' .
		'to a bug in the updater.';
	}

	/**
	 * Manually copy the third-party files that have changed since 9.0.0 because
	 * the old updater does not copy over third-party changes.
	 *
	 * @return bool True if action performed, false otherwise
	 */
	private function manuallyCopyThirdPartyFiles() {
		return false;
	}

	/**
	 * Rerun the integrity check after the update since the repair step has
	 * repaired some invalid copied files.
	 */
	private function recheckIntegrity() {
		\OC::$server->getIntegrityCodeChecker()->runInstanceVerification();
	}

	public function run() {
		if($this->manuallyCopyThirdPartyFiles()) {
			$this->emit('\OC\Repair', 'info', ['Start integrity recheck.']);
			$this->recheckIntegrity();
			$this->emit('\OC\Repair', 'info', ['Finished integrity recheck.']);
		} else {
			$this->emit('\OC\Repair', 'info', ['Rechecking code integrity not necessary.']);
		}
	}
}

